KGInfo
======

.. currentmodule:: pykeen.triples

.. autoclass:: KGInfo
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~KGInfo.iter_extra_repr

   .. rubric:: Methods Documentation

   .. automethod:: iter_extra_repr
